@@ -9,6 +9,15 @@ XML::Filter::XML_Directory_2::Base - base class for creating XML::Directory to s
  package XML::Filter::XML_Directory_2Foo;
  use base qw (XML::Filter::XML_Directory_2::Base);
 
+ sub start_element {
+   my $self = shift;
+   my $data = shift;
+
+   $self->on_enter_start_element($data) || return 0;
+
+   # do stuff here...
+ }
+
 =head1 DESCRIPTION
 
 Base class for creating XML::Directory to something else SAX filters.
@@ -22,10 +31,11 @@ use strict;
 
 use Carp;
 use Exporter;
+use MIME::Types;
 use Digest::MD5 qw (md5_hex);
-use XML::Filter::XML_Directory_Pruner '1.3';
+use XML::Filter::XML_Directory_Pruner '1.1';
 
-$XML::Filter::XML_Directory_2::Base::VERSION   = '1.4.4';
+$XML::Filter::XML_Directory_2::Base::VERSION   = '1.1';
 @XML::Filter::XML_Directory_2::Base::ISA       = qw ( XML::Filter::XML_Directory_Pruner );
 @XML::Filter::XML_Directory_2::Base::EXPORT    = qw ();
 @XML::Filter::XML_Directory_2::Base::EXPORT_OK = qw ();
@@ -36,7 +46,7 @@ $XML::Filter::XML_Directory_2::Base::VERSION   = '1.4.4';
 
 This is a simple helper method designed to save typing. 
 
-Value arguments are
+Value arguments are 
 
 =over
 
@@ -77,32 +87,6 @@ sub attributes {
 
 =head1 OBJECT METHODS
 
-=head2 $pkg->encoding($type)
-
-=cut
-
-sub encoding {
-  my $self = shift;
-  my $type = shift;
-
-  if ($type) {
-    $self->{__PACKAGE__.'__type'} = $type;
-  }
-
-  return $self->{__PACKAGE__.'__type'} || "UTF-8";
-}
-
-=head2 $pkg->set_encoding($type)
-
-Alias for I<encoding>
-
-=cut
-
-sub set_encoding {
-  my $self = shift;
-  $self->encoding(@_);
-}
-
 =head2 $pkg->exclude_root($bool)
 
 By default, XML::Directory will include the directory you pass to the I<XML::Directory(::SAX)::parse_dir> method. 
@@ -144,27 +128,6 @@ sub cwd {
   return $self->{__PACKAGE__.'__cwd'};
 }
 
-=head2 $pkg->current_directory()
-
-Short-cut (ahem) for $pkg->cwd()
-
-=cut
-
-sub current_directory {
-  return $_[0]->cwd();
-}
-
-=head2 $pkg->current_location()
-
-Returns the current location relative to the directory root
-
-=cut
-
-sub current_location {
-  my $self = shift;
-  return $self->{__PACKAGE__.'__loc'};
-}
-
 =head2 $pkg->set_handlers(\%args)
 
 Define one or more valid SAX2 thingies to be called when your package encounters a specific event. Thingies are like any other SAX2 thingy with a few requirements :
@@ -242,13 +205,13 @@ sub set_handlers {
   return 1;
 }
 
-=head2 $pkg->retrieve_handler($event_name)
+=head2 $pkg->get_handler($event_name)
 
 Returns the handler (object) associated with I<$event_name>
 
 =cut
 
-sub retrieve_handler {
+sub get_handler {
   my $self = shift;
   return $self->{__PACKAGE__.'__handlers'}{$_[0]};
 }
@@ -291,13 +254,13 @@ sub set_callbacks {
   return 1;
 }
 
-=head2 $pkg->retrieve_callback($event_name)
+=head2 $pkg->get_callback($event_name)
 
 Return the callback (code reference) associated with I<$event_name>.
 
 =cut
 
-sub retrieve_callback {
+sub get_callback {
   my $self = shift;
   return $self->{__PACKAGE__.'__callbacks'}{$_[0]};
 }
@@ -346,13 +309,51 @@ sub make_link {
 
   my $link = $self->build_uri($data);
 
-  if (my $c = $self->retrieve_callback("link")) {
+  if (my $c = $self->get_callback("link")) {
     $link = &$c($link);
   }
 
   return $link;
 }
 
+=head2 $pkg->mtype($file)
+
+Return the media type, as defined by the I<MIME::Types> package, associated with I<$file>.
+
+=cut
+
+sub mtype {
+  my $self  = shift;
+  my $fname = shift;
+
+  #
+
+  $fname =~ /^(.*)\.([^\.]+)$/;
+  if (! $2) { return undef; }
+
+  if (exists($self->{__PACKAGE__.'__typeof'}{$2})) {
+    return $self->{__PACKAGE__.'__typeof'}{$2};
+  }
+
+  $self->{__PACKAGE__.'__mtypes'} ||= MIME::Types->new()
+    || return undef;
+
+
+  #
+
+  my $mime  = $self->{__PACKAGE__.'__mtypes'}->mimeTypeOf($2);
+
+  if (! $mime) {
+    $self->{__PACKAGE__.'__typeof'}{$2} = undef;
+    return $self->{__PACKAGE__.'__typeof'}{$2};
+  }
+
+  #
+
+  $self->{__PACKAGE__.'__typeof'}{$2} = $mime->mediaType();
+  return $self->{__PACKAGE__.'__typeof'}{$2};
+}
+
 =head2 $pkg->on_enter_start_element(\%data)
 
 This method should be called as the first action in your class' I<start_element> method. It will perform a number of helper actions, like keeping track of the current node level and the absolute path of the current document.
@@ -376,38 +377,29 @@ sub on_enter_start_element {
       $self->{__PACKAGE__.'__head'} = 1;
   }
 
-  if ($data->{Name} =~ /^(directory|file)$/) {
-    $self->{__PACKAGE__.'__'.$1} ++;
-#    map { print " "; } (0..$self->{__PACKAGE__.'__'.$1});
-#    print $self->{__PACKAGE__.'__'.$1} ." ($1) $data->{Attributes}->{'{}name'}->{Value} ".__PACKAGE__."\n";
+  if ($data->{Name} eq "directory") {
+    $self->{__PACKAGE__.'__directory'} ++;
+    # map { print " "; } (0..$self->{__PACKAGE__.'__directory'});
+    # print $self->{__PACKAGE__.'__directory'} ." $data->{Attributes}->{'{}name'}->{Value}\n";
   }
 
   #
 
-  if ((! $self->{__PACKAGE__.'__start'}) && ($data->{Name} =~ /^(file|directory)$/)) {
+  if ((! $self->{__PACKAGE__.'__start'}) && ($data->{Name} eq "directory")) {
 
     if (! exists($self->{__PACKAGE__.'__includeroot'})) {
       $self->{__PACKAGE__.'__start'} = $self->current_level();
       return 1;
     }
-
+    
     else {
 
-      if ((! $self->{__PACKAGE__.'__includeroot'}) &&
-	  (($self->{__PACKAGE__.'__file'} == 1) || ($self->{__PACKAGE__.'__directory'} == 2))) {
-
+      if ((! $self->{__PACKAGE__.'__includeroot'}) && ($self->{__PACKAGE__.'__directory'} == 2)) {
 	$self->{__PACKAGE__.'__start'} = $self->current_level();
 	$self->grow_cwd($data);
-
-	$self->compare($data);
-
-	if (! $self->skip_level()) {
-	  return 1;
-	}
-
-	$self->prune_cwd($data);
-	return 0;
+	return 1;
       }
+
     }
 
   }
@@ -458,8 +450,8 @@ sub on_exit_end_element {
     $self->prune_cwd($data);
   }
 
-  if ($data->{Name} =~ /^(directory|file)$/) {
-    $self->{__PACKAGE__.'__'.$1} --;
+  if ($data->{Name} eq "directory") {
+    $self->{__PACKAGE__.'__directory'} --;
   }
 
   $self->SUPER::on_exit_end_element($data);
@@ -497,7 +489,6 @@ sub grow_cwd {
 
   if ($data->{Name} eq "directory") {
     $self->{__PACKAGE__.'__cwd'} .= "/$data->{Attributes}->{'{}name'}->{Value}";
-    # print STDERR $self->{__PACKAGE__.'__cwd'}."\n";
   }
 
   return 1;
@@ -517,20 +508,18 @@ sub prune_cwd {
 
   if ($data->{Name} eq "directory") {
     $self->{__PACKAGE__.'__cwd'} =~ s/^(.*)\/([^\/]+)$/$1/;
-    # print STDERR "[prune] ".$self->{__PACKAGE__.'__cwd'}."\n";
   }
 
-
   return 1;
 }
 
 =head1 VERSION
 
-1.4.4
+1.1
 
 =head1 DATE
 
-July 22, 2002
+July 03, 2002
 
 =head1 AUTHOR
 
